<?php

class CurlClient
{
    /**
     * POSTリクエストを送信する
     *
     * @param $url
     * @param $data
     * @param array $headers
     * @return bool|string
     */
    public static function doPost($url, $data, array $headers = [])
    {
        $args = array(
            'body'        => $data,
            'timeout'     => '5',
            'redirection' => '5',
            'httpversion' => '1.0',
            'blocking'    => true,
            'headers'     => $headers,
            'cookies'     => array(),
        );

        return wp_remote_post( $url, $args );
    }

    /**
     * Getリクエストを送信する
     *
     * @param $url
     * @param array $data
     * @param array $headers
     * @return bool|string
     */
    public static function doGet($url, array $data, array $headers = [])
    {
        $args = array(
            'body'        => $data,
            'timeout'     => '5',
            'redirection' => '5',
            'httpversion' => '1.0',
            'blocking'    => true,
            'headers'     => $headers,
            'cookies'     => array(),
        );

        return wp_remote_get( $url, $args );
    }

    /**
     * JSONをPOSTする
     *
     * @param $url
     * @param array $data
     * @param array $headers
     * @return bool|string
     */
    public static function doPostJson($url, array $data, array $headers = [])
    {
        $data = json_encode($data);

        $header = [];
        foreach ($headers as $key => $value) {
            $header[$key] = $value;
        }
        $header['Content-type'] = 'application/json';

        $result = self::doPost($url, $data, $header);

        return json_decode($result['body'], true);
    }

    /**
     * JSONをGETする
     *
     * @param $url
     * @param array $data
     * @param array $headers
     * @return bool|string
     */
    public static function doGetJson($url, array $data, array $headers = [])
    {
        $header = [];
        foreach ($headers as $key => $value) {
            $header[$key] = $value;
        }
        $header['Content-type'] = 'application/json';

        $result = self::doGet($url, $data, $header);

        return json_decode($result, true);
    }


}
