<?php

require_once __DIR__ . '/CurlClient.php';

class ImageFlux
{
    public const ORIGIN_KIND_HTTP = 0;
    public const ORIGIN_KIND_S3 = 1;
    
    public $header;

    public function __construct($pure_token)
    {
        $token = rtrim(base64_encode(json_encode(['token' => $pure_token])), '=');

        $this->header = [
            'Authorization' => 'bearer ' . $token
        ];
    }

    /**
     * オリジンを追加する
     *
     * @param $data
     * @return bool|string
     */
    public function addOrigin($data)
    {
        $endpoint = "https://api.imageflux.jp/origin.add";

        $kind = (int) $data['kind'];
        
        $send_data = [
            'origin' => [
                'kind' => $kind,
                'enableSignedUrl' => (bool)$data['enable_signed_url'],
                'signingSecret' => $data['signing_secret'],
            ]
        ];
        $kind_data = [];

        if ($kind === self::ORIGIN_KIND_HTTP) {
            $kind_data = [
                'scheme' => $data['scheme'],
                'host' => $data['host_name'],
                'pathPrefix' => $data['path_prefix'],
            ];
        }
        if ($kind === self::ORIGIN_KIND_S3) {
            $kind_data = [
                'accessKeyID' => $data['access_key_id'],
                'secretAccessKey' => $data['secret_access_key'],
                'region' => $data['region'],
                'bucket' => $data['bucket'],
                'pathPrefix' => $data['path_prefix'],
            ];
        }

        $send_data['origin']['config'] = $kind_data;
        $send_data['origin']['conversionParameters'] = [];

        return CurlClient::doPostJson($endpoint, $send_data, $this->header);
    }

    public function updateOrigin($data)
    {

        $endpoint = "https://api.imageflux.jp/origin.update";

        $kind = (int)$data['kind'];

        $send_data = [
            'origin' => [
                'originID' => (int) $data['origin_id'],
                'kind' => $kind,
                'enableSignedUrl' => (bool)$data['enable_signed_url'],
                'signingSecret' => $data['signing_secret'],
            ]
        ];
        $kind_data = [];

        if ($kind === self::ORIGIN_KIND_HTTP) {
            $kind_data = [
                'scheme' => $data['scheme'],
                'host' => $data['host_name'],
                'pathPrefix' => $data['path_prefix'],
            ];
        }
        if ($kind === self::ORIGIN_KIND_S3) {
            $kind_data = [
                'accessKeyID' => $data['access_key_id'],
                'secretAccessKey' => $data['secret_access_key'],
                'region' => $data['region'],
                'bucket' => $data['bucket'],
                'pathPrefix' => $data['path_prefix'],
            ];
        }

        $send_data['origin']['config'] = $kind_data;
        $send_data['origin']['conversionParameters'] = [];

        return CurlClient::doPostJson($endpoint, $send_data, $this->header);
    }

    /**
     * 転送量データを返す
     *
     * @param $from
     * @param $to
     * @return bool|string
     * @throws Exception
     */
    public function getTransferDataByDatePeriod($from, $to)
    {

        $endpoint = "https://api.imageflux.jp/user.invoice_daily";
//        $endpoint = "https://api.imageflux.jp/statistics.origins";

        $data['from'] = $from;
        $data['to'] = $to;

        error_log(json_encode($data));

        return CurlClient::doPostJson($endpoint, $data, $this->header);
    }

    /**
     * オリジン一覧を返す
     * @param $organizationID
     * @return bool|string
     */
    public function getOriginList()
    {

        $endpoint = "https://api.imageflux.jp/origin.list";

        $data['organizationID'] = 0;

        error_log(json_encode($data));

        return CurlClient::doPostJson($endpoint, $data, $this->header);
    }

    /**
     * オリジン情報の取得
     * @param $origin_id
     * @return bool|string
     */
    public function getOriginInfo($origin_id)
    {
        $endpoint = "https://api.imageflux.jp/origin.info";

        $data['originID'] = (int) $origin_id;

        error_log(json_encode($data));

        return CurlClient::doPostJson($endpoint, $data, $this->header);
    }

    /**
     * オリジンの削除
     * @param $origin_id
     * @return bool|string
     */
    public function deleteOrigin($origin_id)
    {
        $endpoint = "https://api.imageflux.jp/origin.delete";

        $data['originID'] = (int) $origin_id;

        error_log(json_encode($data));

        return CurlClient::doPostJson($endpoint, $data, $this->header);
    }
}