<?php


class ImagefluxSetting
{
    public $prefix;

    protected $fillable = [];

    public function __construct()
    {
        $this->prefix = "image-flux";
    }

    /**
     * DBにオプションをセットする
     *
     * @throws Exception
     */
    public function set($key, $value): void
    {
        if (!in_array($key, $this->fillable, true)) {
            throw new Exception('Unsupported key.');
        }

        update_option($this->prefix . "_" . $key, $value);

        $this->$key = $value;
    }

    /**
     * オプションを取得する(プロパティから再利用もする)
     *
     * @param $key
     * @return mixed
     */
    public function get($key)
    {
        if (!property_exists($this, $key)) {
            $value = get_option($this->prefix . "_" . $key);

            if ($value === false) {
                $value = null;
            }

            $this->$key = $value;
        }

        return $this->$key;
    }

    /**
     * オプションを一括登録する
     *
     * @param $params
     * @return mixed
     * @throws Exception
     */
    public function fillSet($params)
    {
        foreach ($params as $key => $value) {
            if (in_array($key, $this->fillable, true)) {
                $this->set($key, $value);
            }
        }

        return $params;
    }

    public function getParams($keys)
    {
        $params = [];
        foreach ($keys as $key) {
            $params[$key] = $this->get($key);
        }
        return $params;
    }
}