<?php

?>

<div class="wrap" id="imageflux">
    <h1>ImageFlux</h1>

    <h2>オリジン設定</h2>
    <form action="" method='post' id="origin-form">
        <?php wp_nonce_field(self::CREDENTIAL_ACTION_BASIC, self::CREDENTIAL_NAME_BASIC) ?>
        <?php if (($completed_message = get_transient(self::COMPLETE_CONFIG)) !== false) : ?>
            <div class="updated"><p><strong><?php echo esc_html($completed_message) ?></strong></p></div>
        <?php endif; ?>
        <?php if (($error_message = get_transient(self::ERROR_CONFIG)) !== false) : ?>
            <div class="error"><p><strong><?php echo esc_html($error_message) ?></strong></p></div>
        <?php endif; ?>
        <p>
            <label for="api_token">APIトークン：</label>
            <input type="text" id="api_token" name="api_token" data-name="APIトークン" value="<?php echo esc_attr($basic->get('api_token')) ?>" style="width: 800px;" disabled />
        </p>
        <p>
            <label for="kind_http">オリジン種別：</label>
            <input type="radio" name="kind" value="0" id="kind_http" checked required> HTTP
            <input type="radio" name="kind" value="1" id="kind_s3" required> S3
        </p>

        <div id="http_configs">
            <p>
                <label for="scheme">スキーム：</label>
                <select name="scheme" id="scheme" data-name="スキーム">
                    <?php foreach (['http', 'https'] as $value) { ?>
                        <option value="<?php echo esc_attr($value); ?>"><?php echo esc_html($value); ?></option>
                    <?php } ?>
                </select>
            </p>
            <p>
                <label for="host_name">ホスト：</label>
                <input type="text" id="host_name" name="host_name" data-name="ホスト" placeholder="example.com"/>
            </p>
        </div>
        <div id="s3_configs" style="display: none;">
            <p>
                <label for="access_key_id">AWSアクセスキーID：</label>
                <input type="text" id="access_key_id" data-name="AWSアクセスキーID" name="access_key_id" placeholder=""/>
            </p>
            <p>
                <label for="secret_access_key">AWSシークレットアクセスキー：</label>
                <input type="text" id="secret_access_key" data-name="AWSシークレットアクセスキー" name="secret_access_key"  placeholder=""/>
            </p>
            <p>
                <label for="region">AWSリージョン：</label>
                <input type="text" id="region" name="region" data-name="AWSリージョン" placeholder=""/>
            </p>
            <p>
                <label for="bucket">AWSバケット：</label>
                <input type="text" id="bucket" name="bucket" data-name="AWSバケット" placeholder=""/>
            </p>
            <p>
                <label for="path_prefix">エンドポイント：</label>
                <input type="text" id="end_point" name="end_point"  placeholder="" />
            </p>
        </div>
        <p>
            <label for="path_prefix">パスプレフィックス：</label>
            <input type="text" id="path_prefix" name="path_prefix"  placeholder="/"/>
        </p>
        <p>
            <label for="enable_signed_url">署名付きURL：</label>
            <input type="hidden" name="enable_signed_url" value="0">
            <input type="checkbox" id="enable_signed_url_1" name="enable_signed_url" value="1">
            <label for="enable_signed_url_1">有効</label>
        </p>
        <p>
            <label for="signing_secret">署名付きURL使用時の暗号化鍵：</label>
            <input type="text" id="signing_secret" name="signing_secret"  placeholder=""/>
        </p>

        <p><input type='submit' value='保存' class='button button-primary button-large'></p>
    </form>
</div>

<script>
    jQuery('input[name="kind"]').on('change', function () {
        let val = parseInt(jQuery(this).val());

        // HTTP
        if (val === 0) {
            jQuery('#s3_configs').hide();
            jQuery('#http_configs').show();
        }
        // S3
        if (val === 1) {
            jQuery('#http_configs').hide();
            jQuery('#s3_configs').show();
        }
    });

    // バリデーション
    jQuery('#origin-form').on('submit', function () {
        let all_required_keys = ['api_token'];
        let http_required_keys = ['scheme', 'host_name'];
        let s3_required_keys = ['access_key_id', 'secret_access_key', 'region', 'bucket'];

        let errors = [];

        let kind = parseInt(jQuery('input[name="kind"]:checked').val());

        // 全体
        jQuery.each(all_required_keys, function (index, key) {
            if (isValueEmpty(key)) {
                errors.push(jQuery('#' + key).data('name') + "は必須です。\n");
            }
        });

        // HTTP
        if (kind === 0) {
            jQuery.each(http_required_keys, function (index, key) {
                if (isValueEmpty(key)) {
                    errors.push("種別がHTTPのとき、" + jQuery('#' + key).data('name') + "は必須です。\n");
                }
            });
        }

        // S3
        if (kind === 1) {
            jQuery.each(s3_required_keys, function (index, key) {
                if (isValueEmpty(key)) {
                    errors.push("種別がS3のとき、" + jQuery('#' + key).data('name') + "は必須です。\n");
                }
            });
        }

        let checked = jQuery('#enable_signed_url_1').prop('checked');
        if (checked) {
            if (isValueEmpty('signing_secret')) {
                errors.push('署名付きURLを有効にするとき、暗号化鍵を設定してください。')
            }
        }

        if (errors.length > 0) {
            alert(errors.join(""));
            return false;
        }
    });

    function isValueEmpty(id)
    {
        return jQuery('#' + id).val() === "";
    }

</script>